@@ -440,4 +440,11 @@ def resize_col(tbl, col, size=10):
 def human_time(seconds):
     if seconds is None or np.isnan(seconds):
         return None
-    return humanize.precisedelta(timedelta(seconds=int(seconds)), minimum_unit="minutes")
+    hours = humanize.precisedelta(timedelta(seconds=int(seconds)), minimum_unit="hours", format="%0.0f")
+    if len(hours.split(",")) > 2:
+        return hours
+    minutes = humanize.precisedelta(timedelta(seconds=int(seconds)), minimum_unit="minutes", format="%0.0f")
+    if len(minutes.split(",")) > 1:
+        return minutes
+    else:
+        return humanize.precisedelta(timedelta(seconds=int(seconds)), minimum_unit="minutes")
